@@ -12,21 +12,14 @@ COOKIECUTTER = "https://github.com/kiwi-lang/UEDocs"
 # pylint: disable=too-few-public-methods
 class Arguments:
     # fmt: off
-    project : str                    # name of your project
-    no_input: bool          = False  # Do not show user prompts
-    config  : Optional[str] = None   # Configuration file used to initialize the project (json)
+    project : str                   #: name of your project
+    no_input: bool = False          #: Do not show user prompts
+    config  : Optional[str] = None  #: Configuration file used to initialize the project (json)
     # fmt: on
 
 
 class Docs(Command):
-    """Add a Sphinx + Doxygen documentation to a project
-
-    Attributes
-    ----------
-    name: str
-        Name of the project
-
-    """
+    """Add a Sphinx + Doxygen documentation to a project"""
 
     name: str = "docs"
 
